import pandas as pd
from sklearn.model_selection import train_test_split
from sklearn.linear_model import LassoCV
from sklearn.metrics import mean_squared_error

#Load the dataset and preprocess
data = pd.read_csv('c:/users/hjhjhj/desktop/shell.csv')

#Convert STATUS_CONF to binary
data['STATUS_BINARY'] = data['STATUS_CONF'].apply(lambda x: 1 if x == "validated" else 0)

#Convert COUNTRY and PL_NAME to dummy variables
data_dummies = pd.get_dummies(data.drop(columns=['STATUS_CONF', 'IP_INFO']), drop_first=True)

#Split the data into training and test sets
X = data_dummies.drop('STATUS_BINARY', axis=1)
y = data_dummies['STATUS_BINARY']
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=42)

#Apply Lasso regression with cross-validation
lasso = LassoCV(cv=5, random_state=42, max_iter=10000).fit(X_train, y_train)

#Calculate MSE for test set
y_pred = lasso.predict(X_test)
mse = mean_squared_error(y_test, y_pred)

# Print the results
print(f"Optimal alpha value: {lasso.alpha_:.6f}")
print(f"MSE for the test set: {mse:.6f}")

